MRIQC provides a series of image processing workflows
to extract and compute a series of NR (no-reference), IQMs
(image quality metrics) to be used in QAPs (quality
assessment protocols) for MRI (magnetic
resonance imaging).